@@ -10,7 +10,7 @@ import dash_html_components as html
 import dash.dependencies as dd
 import plotly
 
-from dash.dependencies import Input, State, Output, MATCH, ALL, ALLSMALLER, _Wildcard
+from dash.dependencies import Input, Output, MATCH, ALL, ALLSMALLER, _Wildcard, ClientsideFunction
 from dash.development.base_component import Component
 from flask import session
 from flask_caching.backends import FileSystemCache, RedisCache
@@ -441,10 +441,11 @@ class EnrichedOutput(Output):
      Like a normal Output, includes additional properties related to storing the data.
     """
 
-    def __init__(self, component_id, component_property, backend=None, session_check=None):
+    def __init__(self, component_id, component_property, backend=None, session_check=None, arg_check=True):
         super().__init__(component_id, component_property)
         self.backend = backend
         self.session_check = session_check
+        self.arg_check = arg_check
 
 
 class ServersideOutput(EnrichedOutput):
@@ -455,9 +456,10 @@ class ServersideOutput(EnrichedOutput):
 
 class ServersideOutputTransform(DashTransform):
 
-    def __init__(self, backend=None, session_check=True):
+    def __init__(self, backend=None, session_check=True, arg_check=True):
         self.backend = backend if backend is not None else FileSystemStore()
         self.session_check = session_check
+        self.arg_check = arg_check
 
     def init(self, dt):
         # Set session secret (if not already set).
@@ -483,6 +485,7 @@ class ServersideOutputTransform(DashTransform):
                 if not isinstance(output, ServersideOutput) and not memoize:
                     continue
                 output.backend = output.backend if output.backend is not None else self.backend
+                output.arg_check = output.arg_check if output.arg_check is not None else self.arg_check
                 output.session_check = output.session_check if output.session_check is not None else self.session_check
             # Keep track of server side callbacks.
             if serverside or memoize:
@@ -550,7 +553,7 @@ def _pack_outputs(callback):
                     is_trigger = trigger_filter(callback["sorted_args"])
                     filtered_args = [arg for i, arg in enumerate(args) if not is_trigger[i]]
                     # Generate unique ID.
-                    unique_id = _get_cache_id(f, output, list(filtered_args), output.session_check)
+                    unique_id = _get_cache_id(f, output, list(filtered_args), output.session_check, output.arg_check)
                     unique_ids.append(unique_id)
                     if not output.backend.has(unique_id):
                         update_needed = True
@@ -575,7 +578,7 @@ def _pack_outputs(callback):
                     # Filter out Triggers (a little ugly to do here, should ideally be handled elsewhere).
                     is_trigger = trigger_filter(callback["sorted_args"])
                     filtered_args = [arg for i, arg in enumerate(args) if not is_trigger[i]]
-                    unique_id = _get_cache_id(f, output, list(filtered_args), output.session_check)
+                    unique_id = _get_cache_id(f, output, list(filtered_args), output.session_check, output.arg_check)
                     output.backend.set(unique_id, data[i])
                     # Replace only for server side outputs.
                     if serverside_output:
@@ -587,13 +590,24 @@ def _pack_outputs(callback):
     return packed_callback
 
 
-def _get_cache_id(func, output, args, session_check=None):
-    all_args = [func.__name__, _create_callback_id(output)] + list(args)
+def _get_cache_id(func, output, args, session_check=None, arg_check=True):
+    all_args = [func.__name__, _create_callback_id(output)]
+    if arg_check:
+        all_args += list(args)
     if session_check:
         all_args += [_get_session_id()]
     return hashlib.md5(json.dumps(all_args).encode()).hexdigest()
 
 
+def _get_output_id(callback):
+    if isinstance(callback['f'], (ClientsideFunction, str)):
+        f_repr = repr(callback['f'])  # handles clientside functions
+    else:
+        f_repr = f"{callback['f'].__module__}.{callback['f'].__name__}"  # handles Python functions
+    f_hash = hashlib.md5(f_repr.encode()).digest()
+    return str(uuid.UUID(bytes=f_hash, version=4))
+
+
 # Interface definition for server stores.
 
 class ServerStore:
@@ -661,7 +675,7 @@ class NoOutputTransform(DashTransform):
     def _apply(self, callbacks):
         for callback in callbacks:
             if len(callback[dd.Output]) == 0:
-                output_id = str(uuid.uuid4())
+                output_id = _get_output_id(callback)
                 hidden_div = html.Div(id=output_id, style={"display": "none"})
                 callback[dd.Output] = [dd.Output(output_id, "children")]
                 self.hidden_divs.append(hidden_div)
